import unittest
import mock

from src import core


class TestOpenUrl(unittest.TestCase):

    def setUp(self):
        super(TestOpenUrl, self).setUp()
        self.func = core.open_url

    @mock.patch('click.launch')
    def test_run(self, mock_launch):
        """

        :param mock.MagicMock mock_launch: mock
        """
        self.func('https://github.com')
        self.assertEqual(1, mock_launch.call_count)



import logging
import sys

import click
from click_didyoumean import DYMMixin
from click_help_colors import HelpColorsGroup

from src import core

logger = logging.getLogger('voodoo')
logging.basicConfig()
logger.setLevel(logging.INFO)


class AllGroup(DYMMixin, HelpColorsGroup, click.Group):  # pylint: disable=too-many-public-methods
    pass


@click.group(
    cls=AllGroup,
    help_headers_color='yellow',
    help_options_color='green'
)
@click.version_option()
def entry_point():
    pass


@entry_point.command()
@click.argument('user', required=False)
@click.argument('repo', required=False)
def github(user='', repo=''):
    url = 'https://github.com'
    if user:
        url = '/'.join([url, user])
        if repo:
            url = '/'.join([url, repo])
    core.open_url(url)


@entry_point.command()
def inbox():
    core.open_url("https://inbox.google.com")


if __name__ == '__main__':
    sys.exit(entry_point())



import unittest

from click.testing import CliRunner
import mock

from src import cli


class TestGithub(unittest.TestCase):

    def setUp(self):
        super(TestGithub, self).setUp()
        self.runner = CliRunner()
        self.command = cli.github
        self.url = 'https://github.com'

    @mock.patch('src.core.open_url')
    def test_no_argument(self, mock_open_url):
        """ Test the command without any of the optional arguments.

        :param mock.MagicMock mock_open_url: mock
        :return:
        """
        result = self.runner.invoke(self.command)
        self.assertEqual(0, result.exit_code)
        self.assertEqual(1, mock_open_url.call_count)
        self.assertEqual(mock.call(self.url), mock_open_url.call_args)

    @mock.patch('click.launch')
    def test_user(self, mock_launch):
        """ Test with only one argument.

        :param mock.MagicMock mock_launch: mock
        """
        user = 'foutoucour'
        result = self.runner.invoke(self.command, [user])
        self.assertEqual(0, result.exit_code)
        self.assertEqual(mock.call('{}/{}'.format(self.url, user)), mock_launch.call_args)

    @mock.patch('click.launch')
    def test_user_repo(self, mock_launch):
        """ Test with the all 2 arguments

        :param mock.MagicMock mock_launch: mock
        """
        user = 'foutoucour'
        repo = 'info'
        result = self.runner.invoke(self.command, [user, repo])
        self.assertEqual(0, result.exit_code)
        self.assertEqual(mock.call('{}/{}/{}'.format(self.url, user, repo)), mock_launch.call_args)


class TestInbox(unittest.TestCase):
    def setUp(self):
        super(TestInbox, self).setUp()
        self.runner = CliRunner()
        self.command = cli.inbox
        self.url = 'https://inbox.google.com'

    @mock.patch('src.core.open_url')
    def test_no_argument(self, mock_open_url):
        """ Test the command without any arguments.

        :param mock.MagicMock mock_open_url: mock
        :return:
        """
        result = self.runner.invoke(self.command)
        self.assertEqual(0, result.exit_code)
        self.assertEqual(1, mock_open_url.call_count)
        self.assertEqual(mock.call(self.url), mock_open_url.call_args)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import find_packages, setup
from src import manifest

setup(
    name=manifest.name,
    use_scm_version=True,
    setup_requires=['setuptools_scm', 'pytest_runner'],
    description=manifest.description,
    author=manifest.author,
    author_email=manifest.email,
    url=manifest.url,
    packages=find_packages(exclude=('tests',)),
    entry_points='''
        [console_scripts]
        nepo=src.cli:entry_point
    ''',
    install_requires=[
        'click',
        'click-didyoumean',
        'click-help-colors',
        'crayons',
    ],
    tests_require=[
        'pytest',
        'pytest-cov',
        'pytest-random-order',
        'mock',
    ],
    include_package_data=True,
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
)
